Clazz.declarePackage("JU");
Clazz.load(["java.lang.RuntimeException"], "JU.JSONException", null, function(){
var c$ = Clazz.declareType(JU, "JSONException", RuntimeException);
});
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
